package de.intevation.gnv.artifactdatabase.objects;

import java.util.Collection;
import java.util.Map;

/**
 * Interface which extends the funtionality of the Interface
 * <code>ArtifactObject</code> with methods for storing and retrieving 
 * optional Parameters.
 * @author <a href="mailto:tim.englich@intevation.de">Tim Englich</a>
 */
public interface ParametrizedArtifactObject extends ArtifactObject {

    /**
     * Returns the Parameters which could be used to manage (e.g. create) an
     * ArtifactObject.
     * @return a map storing parameters.
     */
    Map<String, Collection<String>> getParameters();

    /**
     * Add a further parameter to the parameter map.
     *
     * @param key the Key of the Parameter (unique)
     * @param values the Values of the Parameter
     */
    void addParameters(String key, Collection<String> values);
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :